
# 0.0.6 (2022-05-17)

### Added

- Allow specify a `subdir` folder in which store/read pickle file


# 0.0.5 (2022-02-07)

### Added

- Adds `nbresult_checker` script listing pickle files containing complex python data types
